@@ -1,5 +1,13 @@
 context("Stock-Recruitment")
 
+test_that("srFunShow() messages",{
+  expect_error(srFunShow("Derek"),"should be one of")
+  expect_error(srFunShow(type="BevertonHolt",param=0),"must be from")
+  expect_error(srFunShow(type="BevertonHolt",param=5),"must be from")
+  expect_error(srFunShow(type="Ricker",param=0),"must be from")
+  expect_error(srFunShow(type="Ricker",param=4),"must be from")
+})
+
 test_that("srFuns() errors and warnings",{
   ## wrong type
   expect_error(srFuns(type="Derek"),"should be one")
@@ -57,6 +65,8 @@ data(CodNorwegian)
 CodNorwegian$fyear <- factor(CodNorwegian$year)
 
 test_that("srStarts() errors and warnings",{
+  ## Asked for a dynamicPlot, which now does not exist
+  expect_warning(srStarts(recruits~stock,data=CodNorwegian,dynamicPlot=TRUE),"functionality has been moved to")
   ## wrong type
   expect_error(srStarts(type="Derek"))
   ## wrong parameterization choices
